import type { PluginConfig, TagAttrs, VTPComponentProps, CodeExtractorOptions } from '../types';
import MarkdownIt from 'markdown-it';
import type { Token } from 'markdown-it/index.js';
export declare function parseAttrs(attrsString: string): TagAttrs;
export declare function getAttributeOrElse(token: Token, attrName: string, defaultValue: string, parseJson?: boolean): string | boolean;
/**
 * Generates the HTML for the templ preview component.
 * @param md - The MarkdownIt instance.
 * @param componentProps - The properties for the preview component.
 * @param extractorOptions - The options for the code extractor.
 * @returns The HTML string for the templ preview component.
 */
export declare function generateTemplPreviewComponentHtml(md: MarkdownIt, componentProps: VTPComponentProps, extractorOptions?: CodeExtractorOptions): string;
/**
 * Handles the operation mode for generating template and HTML file paths.
 *
 * @param {string} id - The identifier of the source file.
 * @param {string} serverRoot - The root directory of the server.
 * @param {Partial<PluginConfig>} options - Configuration options for the plugin.
 * @param {string} srcValue - The source value to be used in the file names.
 * @returns {{ templFile: string; htmlFile: string }} - Object containing the paths for the template and HTML files.
 * @throws {Error} - Throws an error if the mode is unknown or not defined in options.
 */
export declare function handleOpMode(id: string, serverRoot: string, options: Partial<PluginConfig>, srcValue: string): {
    templFile: string;
    htmlFile: string;
};
